# Reporte COVID-19 en México y Michoacán
### Dr. Rafael Lara-Hernández, Dr. Héctor Javier Vergara-Hernández, M. C. Gerardo Marx Chávez-Campos 
![](figuras/sedeam-logo.jpg)
### 16 de abril del 2020

---
## Introducción

El presente reporte muestra la actualización del comportamiento de los casos reportados como confirmados de COVID-19 por la Secretaría de Salud (SS) de México desde el 23 de marzo, cuando el Laboratorio Nacional SEDEAM inicio el reporte. Día a día se actualizan en el repositorio, con la intensión de monitorear la evolución de la PANDEMIA en nuestro país y en el estado de Michoacán. El día de hoy se cumplen 37 días desde que la OMS catalogó el COVID-19 como una pandemia. Los datos son usados para el cálculo y análisis de parámetros como: tasa de crecimiento diaria, acumulación de casos positivos y promedio de crecimiento e incremento de casos confirmados de COVID-19. Con la información se han desarrollo tres modelos para estimar, a la fecha, la dinámica de la urgencia sanitaria en México. Los modelos estudiados son: exponencial, polinomial y logarítmico. Cada caso es presentado y analizado en las siguientes secciones. Los resultados muestran que al 16 de abril y como país, representamos el 0.32% del total de casos confirmados y el 0.59% de casos nuevos a nivel mundial aproximadamente, resgistrando un decremento respecto al día anterior en la participación de casos nuevos. Además, se estudia el caso particular del estado de Michoacán ya que el laboratorio nacional SEDEAM tiene una sede en la capital (MORELIA). El reporte no trata de predecir el futuro, sino de describir la evolución diaria de la Pandemia en nuestro País y nuestro Estado. Este repositorio es actualizado todos los días y su historial queda guardado para un análisis final del fenómeno.

### Modelo exponencial

El modelo exponencial se ajusta para una tasa diaria de crecimiento de contagio de 0.106 la cual presentó un ligero descenso respecto a la tasa del día anterior. A este ritmo se puede estimar un promedio de 7.09 casos confirmados por hora desde que se inició el registro y de 18.75 casos confirmados por hora durante la jornada de hoy. En la siguiente figura se pueden observar los registros diarios representados por círculos, mientras que el comportamiento del modelo se pude observar con una línea gris. Este modelo generó una estimación con un error del 7% por arriba del registro actual.

![](figuras/Abril16-1.png)


### Modelo logarítmico 

Por su parte el modelo logarítmico, del tipo ln[f(x)]=ax+b, destacando la tendencia del crecimiento en el número de casos confirmados desde el inicio del registro de los datos. Véase la siguiente figura.

![](figuras/Abril16-3.png)

### Factor de crecimiento de los casos reportados

El factor de crecimiento se estima día a día respecto a los casos confirmados. La jornada no presentó cambio con respecto al día anterior, registrando un factor de contagio de 1.08 al registrar 450 nuevos casos confirmados.

![](figuras/Abril16-4.png)

La tasa de letalidad continúa en ascenso, registrando un acumulado de 486 decesos para una tasa de 7.72 defunciones por cada 100 casos confirmados a nivel nacional por arriba de la tasa global de 6.6, respecto a los casos confirmados respectivamente, en la jornada de hoy se presentaron 37 nuevos fallecimientos, lo que representa un 14% menos de los fallecimientos registrados el día anterior. Al respecto se presenta la gráfica, la cual se ajusta a un modelo tipo exponencial.

![](figuras/Abril16-8.png)

### Estimación y análisis a partir del modelo exponencial y el modelo de Gompertz

Adicionalmente se analiza el incremento diario de casos confirmados, el cual se ha venido justado a un modelo de tipo exponencial con un incremento en el actual dato registrado, véase la figura de abajo. Este modelo permite observar el crecimiento de casos confirmados de una manera oscilatoria sobre la línea de tendencia, que para este 16 de abril registró una tasa aproximada de 0.079 día transcurrido por caso confirmado, pero con un error significativo.

![](figuras/Abril16-5.png)

La función de Gompertz, es ampliamente utilizada en biología como modelo de regresión para estudiar el crecimiento de las poblaciones de animales, bacterias, crecimiento de tumores y supervivencia de pacientes de cáncer, y por supuesto modelos de infección.

La curva de Gompertz o la función de Gompertz, es un tipo de modelo matemático para una serie de tiempo que lleva el nombre de su creador Benjamin Gompertz (1779-1865). Es una función sigmoidea que tiene forma de sigma mayúscula. Muchos procesos naturales de sistemas complejos muestran una progresión temporal desde unos niveles bajos al inicio, hasta acercarse a un clímax o punto máximo transcurrido un cierto tiempo; la transición se produce en una región caracterizada por una fuerte aceleración intermedia.

La función de Gompertz es muy similar a la función logística, pero se diferencia de ella en que es asimétrica. El crecimiento es más rápido al principio de la curva que al final (Ver siguiente Figura). Esta pequeña diferencia la hace más apropiada para describir el crecimiento biológico.

![](figuras/Fig Gompertz.JPG)

La función de Gompertz es la solución a la ecuación diferencial que describe los cambios en la población (P) con el paso del tiempo (t) en función de su capacidad de crecimiento intrínseca (c constante) y la máxima población que el ecosistema puede soportar, lo que se define como capacidad de carga (K, carrying capacity).
La ecuación diferencial que describe el comportamiento de las poblaciones es:
        dP/dt = c ln(K/P)P

Esta ecuación cuando se integra y resuelve nos da la función de Gompertz, que describe los cambios en la población en función del tiempo:
        P(t) = K e^-ln(K/P0) e^-ct

Donde P0 es el tamaño de la población inicial. Esta ecuación se puede escribir de varias formas equivalentes.

Para este modelo se corrieron los datos de los casos confirmados de COVID19 en México, desde el reporte del 28 de febrero cuando se registraron los 2 primeros casos confirmados hasta los 5847 del día 15 de abril, toda vez que el modelo exponencial comenzaba a alejarse del comportamiento real y por lo tanto el ajuste de este modelo presentaba un error mayor al 7% en las estimaciones. De igual manera y una vez que el equipo experto de la Secretaria de Salud del Gobierno Federal explicara y determinara las fechas estimadas para la definición de estrategias tanto para la fase 3 como para el levantamiento gradual de la contiengencia epidemiológica en el territorio nacional y habiendo corrido por nuestra parte, en varias ocasiones el modelo de Gompertz referido por el grupo experto como un modelo válido para el ajuste y para la estimación, el equipo de análisis del Laboratorio Nacional de Sistemas Embebidos sede Morelia, decidimos explicar en función de esta información dicho modelo y clarificar aspectos relevantes del mismo para continuar describiendo el comportamiento tanto a nivel nacional como a nivel estatal.

El modelo matemático resultante fue el siguiente:
        Y = a * EXP (-EXP (b – c * t))
donde:
        Y es el número de nuevos casos confirmado por día
        K, b y c son constantes del modelo que nos serviran para explicar el comportamiento del fenómeno
        t es el tiempo (días) transcurrido desde el registro de los datos

El modelo obtenido fue:
        Caso nuevos = 932.457 * EXP (-EXP (2.50303 – 0.0585782 * t))

Donde, K es la capacidad de carga del sistema y refleja el máximo de casos que se van a alcanzar, correspondiendo a la asíntota superior, por lo que el valor máximo de casos confirmados esperado en la Republica Mexicana sería de 933 nuevos casos por día, donde se habrá de estabilizar el crecimiento, para una constante de crecimiento por día de c = 0.0585782
El modelo de Gompertz como todos los modelos sigmoideos presentan 4 fases: la fase lag o de adaptación y tambien llamada de latencia, la fase exponencial, la fase estacionaria y la de muerte, para lo cual se calculan los siguientes tiempos:

La duración de la fase de latencia o desarrollo se obtiene de la razón (b-1)/c y corresponde a 25.65 días, esta fase representa un período de transición antes de comenzar el crecimiento exponencial, que concluyó aproximadamente entre el día 23 y 25 de marzo. 
En la fase exponecial es importante calcular la velocidad específica de crecimiento (VEC) que se obtiene del producto de K*c y corresponde aproximadamente a 55 días,  que se mantiene hasta la fecha del 17 de mayo, dando paso a la fase estacionaria.

Con base en este modelo es posible estimar el comportamiento del fenómeno y establecer los casos confirmados, los contagios totales no identificados, así como los fallecimientos con base en las tasas que se actualizan día a día.



De los análisis realizados durante los últimos días con los diferentes modelos, se pueden establecer para el día 17 de abril una estimación de 6782 a 6801 casos confirmados para un valor esperado de 6792, significando un incremento estimado de entre 485 y 504, para un valor esperado de 495 nuevos casos.

Tomando el cuenta el factor establecido por la Secretaria de Salud para la estimación total de contagios a la fecha sería de 52454 contagios posibles en todo el país, que para esta jornada se puede considerar existen aproximadamente 40114 posibles contagios existentes no identificados.


---

## Estimaciones para el estado de Michoacán

Para el caso de Michoacán, hoy 16 de abril se reportaron 21 nuevos casos e triple respecto al día anterior, acumulando un total de 100 casos confirmados que representan el 1.59% de casos confirmados y el 4.66% de los casos nuevos del total nacional respectivamente. Para el día de hoy el modelo lineal presentó un error significativo, por lo que se corrió el modelo exponencial el cual ajustó de forma adecuada y explicando la dinámica de la Pandemia para el Estado.


![](figuras/Abril16-6-expo.png)

El factor de crecimiento diario de casos confirmados con virus COVID-19 presentó un incremento al pasar de 1.10 a 1.27, el cual es mayor al factor nacional para esta jornada de 1.08. Por otra parte, este factor alcanzón el pico mas alto de los días sobrepasando del factor promedio acumulado de 1.14 en Michoacán así como el promedio nacional acumulado de 1.21.

![](figuras/Abril16-7.png)

Con relación al total de fallecimientos, a la fecha se han acumulado un total de 14 defunciones representando el 2.88% del total nacional registrando una tasa de letalidad de14 defunciones por cada 100 casos confirmados.

Respecto a las distribución en el territorio del Estado, el municipio de Morelia concentra el 28% de casos confirmados, el municipio de Lázaro Cárdenas el 23%, Uruapan 8%, La Piedad 7%, Tzintzuntzan y Venustiano Carranza 6% respectivamente, el restante 22% distribuido en 16 municipios. Lo que representa una expansión de la Pandemia en el 19.5% de los municipios del Estado, siendo el municipio de Lázaro Cárdenas el que mayor casos confirmados presentó durante el día de hoy. Respecto a la edad de los casos confirmados, se mantiene la prevalencia de las personas de género masculino mayores de 60 años. 

Del análisis anterior, se desprende una estimación para el día 17 de abril de 110 a 127 casos confirmados en el Estado.

Tomando el cuenta el factor establecido por la Secretaria de Salud para la estimación total de contagios a la fecha serían de 833 contagios posibles en todo el Estado, que para esta jornada se puede estimar un total aproximado de 630 posibles contagios existentes no identificados.




